@@ -88,7 +88,7 @@ fn main() -> Result<()> {
             DisplayMode::Standard | DisplayMode::StandardAlphabetical => (true, false),
         };
         for path in &config.paths {
-            debug!("processing path: {:?}", path);
+            debug!("processing path: {}", path.display());
 
             let repository_collection =
                 RepositoryCollector::run(path, include_email, include_submodules)?;
@@ -106,9 +106,8 @@ mod tests {
     use collector::RepositoryCollection;
     use git2::ErrorCode;
     use git2::Oid;
-    use git2::Repository;
     use git2::Signature;
-    use pretty_assertions::assert_eq;
+    use git2::{Repository, RepositoryInitOptions};
     use repository_view::RepositoryView;
     use status::Status;
     use std::fs::File;
@@ -128,6 +127,7 @@ mod tests {
         //     │   └── file
         //     ├── two (repo)
         //     ├── three (repo)
+        //     ├── eight (worktree repo)
         //     └── nested
         //         ├── four (repo)
         //         ├── five (repo)
@@ -144,48 +144,58 @@ mod tests {
         let repo_five = create_directory(&nested, "five")?;
         let repo_six = create_directory(&nested, "six")?;
         let repo_seven = create_directory(&nested, "seven")?;
+        // repo_eight doesn't need a dir. It's created via 'worktree add'
+
+        // Setup repo opts
+        let mut opts = RepositoryInitOptions::new();
+        let initial_head = "main";
+        opts.initial_head(initial_head);
 
         // Repo One
-        Repository::init(&repo_one)?;
+        Repository::init_opts(&repo_one, &opts)?;
         create_file(&repo_one)?;
 
         // Repo Two
-        Repository::init(&repo_two)?;
+        Repository::init_opts(&repo_two, &opts)?;
 
         // Repo Three
-        Repository::init(&repo_three)?;
+        Repository::init_opts(&repo_three, &opts)?;
 
         // Repo Four
-        let repository = Repository::init(&repo_four)?;
-        if let Err(e) = repository.remote("origin", "https://github.com/nickgerace/gfold") {
-            if e.code() != ErrorCode::Exists {
-                return Err(e.into());
-            }
+        let repository = Repository::init_opts(&repo_four, &opts)?;
+        if let Err(e) = repository.remote("origin", "https://github.com/nickgerace/gfold")
+            && e.code() != ErrorCode::Exists
+        {
+            return Err(e.into());
         }
 
         // Repo Five
-        Repository::init(&repo_five)?;
+        Repository::init_opts(&repo_five, &opts)?;
         create_file(&repo_five)?;
 
         // Repo Six
-        let repository = Repository::init(&repo_six)?;
-        if let Err(e) = repository.remote("fork", "https://github.com/nickgerace/gfold") {
-            if e.code() != ErrorCode::Exists {
-                return Err(e.into());
-            }
+        let repository = Repository::init_opts(&repo_six, &opts)?;
+        if let Err(e) = repository.remote("fork", "https://github.com/nickgerace/gfold")
+            && e.code() != ErrorCode::Exists
+        {
+            return Err(e.into());
         }
         commit_head_and_create_branch(&repository, "feat")?;
 
         // Repo Seven
-        let repository = Repository::init(&repo_seven)?;
-        if let Err(e) = repository.remote("origin", "https://github.com/nickgerace/gfold") {
-            if e.code() != ErrorCode::Exists {
-                return Err(e.into());
-            }
+        let repository = Repository::init_opts(&repo_seven, &opts)?;
+        if let Err(e) = repository.remote("origin", "https://github.com/nickgerace/gfold")
+            && e.code() != ErrorCode::Exists
+        {
+            return Err(e.into());
         }
         commit_head_and_create_branch(&repository, "needtopush")?;
         repository.set_head("refs/heads/needtopush")?;
 
+        // Repo Eight
+        let worktree_path = root.path().join("eight");
+        repository.worktree("working-in-a-tree", &worktree_path, None)?;
+
         // Generate the collection directly with a default config and ensure the resulting views
         // match what we expect.
         let mut expected_collection = RepositoryCollection::new();
@@ -195,6 +205,14 @@ mod tests {
             .expect("could not convert PathBuf to &str")
             .to_string();
         let mut expected_views = vec![
+            RepositoryView::finalize(
+                &worktree_path,
+                Some("working-in-a-tree".to_string()),
+                Status::Unpushed,
+                Some("https://github.com/nickgerace/gfold".to_string()),
+                None,
+                Vec::with_capacity(0),
+            )?,
             RepositoryView::finalize(
                 &repo_one,
                 Some("HEAD".to_string()),
@@ -247,7 +265,7 @@ mod tests {
             )?,
             RepositoryView::finalize(
                 &repo_six,
-                Some("master".to_string()),
+                Some(initial_head.to_string()),
                 Status::Unpushed,
                 Some("https://github.com/nickgerace/gfold".to_string()),
                 None,
@@ -286,10 +304,10 @@ mod tests {
         let parent = parent.as_ref();
         let new_directory = parent.join(name);
 
-        if let Err(e) = fs::create_dir(&new_directory) {
-            if e.kind() != io::ErrorKind::AlreadyExists {
-                return Err(e);
-            }
+        if let Err(e) = fs::create_dir(&new_directory)
+            && e.kind() != io::ErrorKind::AlreadyExists
+        {
+            return Err(e);
         }
         Ok(new_directory)
     }
@@ -319,10 +337,7 @@ mod tests {
         // "revparse_single" cannot be converted into a commit, then it isn't a commit and we know
         // there is no parent _commit_.
         let maybe_parent = match repository.revparse_single("HEAD") {
-            Ok(object) => match object.into_commit() {
-                Ok(commit) => Some(commit),
-                Err(_) => None,
-            },
+            Ok(object) => object.into_commit().ok(),
             Err(e) if e.code() == ErrorCode::NotFound => None,
             Err(e) => return Err(e.into()),
         };
